// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Generated code. DO NOT EDIT!

using gax = Google.Api.Gax;
using sys = System;
using linq = System.Linq;

namespace Google.Android.OverTheAir.V1
{
    /// <summary>
    /// Resource name for the 'chart' resource.
    /// </summary>
    public sealed partial class ChartName : gax::IResourceName, sys::IEquatable<ChartName>
    {
        private static readonly gax::PathTemplate s_template = new gax::PathTemplate("deployments/{deployment}/groups/{group}/charts/{chart}");

        /// <summary>
        /// Parses the given chart resource name in string form into a new
        /// <see cref="ChartName"/> instance.
        /// </summary>
        /// <param name="chartName">The chart resource name in string form. Must not be <c>null</c>.</param>
        /// <returns>The parsed <see cref="ChartName"/> if successful.</returns>
        public static ChartName Parse(string chartName)
        {
            gax::GaxPreconditions.CheckNotNull(chartName, nameof(chartName));
            gax::TemplatedResourceName resourceName = s_template.ParseName(chartName);
            return new ChartName(resourceName[0], resourceName[1], resourceName[2]);
        }

        /// <summary>
        /// Tries to parse the given chart resource name in string form into a new
        /// <see cref="ChartName"/> instance.
        /// </summary>
        /// <remarks>
        /// This method still throws <see cref="sys::ArgumentNullException"/> if <paramref name="chartName"/> is null,
        /// as this would usually indicate a programming error rather than a data error.
        /// </remarks>
        /// <param name="chartName">The chart resource name in string form. Must not be <c>null</c>.</param>
        /// <param name="result">When this method returns, the parsed <see cref="ChartName"/>,
        /// or <c>null</c> if parsing fails.</param>
        /// <returns><c>true</c> if the name was parsed successfully; <c>false</c> otherwise.</returns>
        public static bool TryParse(string chartName, out ChartName result)
        {
            gax::GaxPreconditions.CheckNotNull(chartName, nameof(chartName));
            gax::TemplatedResourceName resourceName;
            if (s_template.TryParseName(chartName, out resourceName))
            {
                result = new ChartName(resourceName[0], resourceName[1], resourceName[2]);
                return true;
            }
            else
            {
                result = null;
                return false;
            }
        }

        /// <summary>
        /// Constructs a new instance of the <see cref="ChartName"/> resource name class
        /// from its component parts.
        /// </summary>
        /// <param name="deploymentId">The deployment ID. Must not be <c>null</c>.</param>
        /// <param name="groupId">The group ID. Must not be <c>null</c>.</param>
        /// <param name="chartId">The chart ID. Must not be <c>null</c>.</param>
        public ChartName(string deploymentId, string groupId, string chartId)
        {
            DeploymentId = gax::GaxPreconditions.CheckNotNull(deploymentId, nameof(deploymentId));
            GroupId = gax::GaxPreconditions.CheckNotNull(groupId, nameof(groupId));
            ChartId = gax::GaxPreconditions.CheckNotNull(chartId, nameof(chartId));
        }

        /// <summary>
        /// The deployment ID. Never <c>null</c>.
        /// </summary>
        public string DeploymentId { get; }

        /// <summary>
        /// The group ID. Never <c>null</c>.
        /// </summary>
        public string GroupId { get; }

        /// <summary>
        /// The chart ID. Never <c>null</c>.
        /// </summary>
        public string ChartId { get; }

        /// <inheritdoc />
        public gax::ResourceNameKind Kind => gax::ResourceNameKind.Simple;

        /// <inheritdoc />
        public override string ToString() => s_template.Expand(DeploymentId, GroupId, ChartId);

        /// <inheritdoc />
        public override int GetHashCode() => ToString().GetHashCode();

        /// <inheritdoc />
        public override bool Equals(object obj) => Equals(obj as ChartName);

        /// <inheritdoc />
        public bool Equals(ChartName other) => ToString() == other?.ToString();

        /// <inheritdoc />
        public static bool operator ==(ChartName a, ChartName b) => ReferenceEquals(a, b) || (a?.Equals(b) ?? false);

        /// <inheritdoc />
        public static bool operator !=(ChartName a, ChartName b) => !(a == b);
    }

    /// <summary>
    /// Resource name for the 'config' resource.
    /// </summary>
    public sealed partial class ConfigName : gax::IResourceName, sys::IEquatable<ConfigName>
    {
        private static readonly gax::PathTemplate s_template = new gax::PathTemplate("deployments/{deployment}/configs/{config}");

        /// <summary>
        /// Parses the given config resource name in string form into a new
        /// <see cref="ConfigName"/> instance.
        /// </summary>
        /// <param name="configName">The config resource name in string form. Must not be <c>null</c>.</param>
        /// <returns>The parsed <see cref="ConfigName"/> if successful.</returns>
        public static ConfigName Parse(string configName)
        {
            gax::GaxPreconditions.CheckNotNull(configName, nameof(configName));
            gax::TemplatedResourceName resourceName = s_template.ParseName(configName);
            return new ConfigName(resourceName[0], resourceName[1]);
        }

        /// <summary>
        /// Tries to parse the given config resource name in string form into a new
        /// <see cref="ConfigName"/> instance.
        /// </summary>
        /// <remarks>
        /// This method still throws <see cref="sys::ArgumentNullException"/> if <paramref name="configName"/> is null,
        /// as this would usually indicate a programming error rather than a data error.
        /// </remarks>
        /// <param name="configName">The config resource name in string form. Must not be <c>null</c>.</param>
        /// <param name="result">When this method returns, the parsed <see cref="ConfigName"/>,
        /// or <c>null</c> if parsing fails.</param>
        /// <returns><c>true</c> if the name was parsed successfully; <c>false</c> otherwise.</returns>
        public static bool TryParse(string configName, out ConfigName result)
        {
            gax::GaxPreconditions.CheckNotNull(configName, nameof(configName));
            gax::TemplatedResourceName resourceName;
            if (s_template.TryParseName(configName, out resourceName))
            {
                result = new ConfigName(resourceName[0], resourceName[1]);
                return true;
            }
            else
            {
                result = null;
                return false;
            }
        }

        /// <summary>
        /// Constructs a new instance of the <see cref="ConfigName"/> resource name class
        /// from its component parts.
        /// </summary>
        /// <param name="deploymentId">The deployment ID. Must not be <c>null</c>.</param>
        /// <param name="configId">The config ID. Must not be <c>null</c>.</param>
        public ConfigName(string deploymentId, string configId)
        {
            DeploymentId = gax::GaxPreconditions.CheckNotNull(deploymentId, nameof(deploymentId));
            ConfigId = gax::GaxPreconditions.CheckNotNull(configId, nameof(configId));
        }

        /// <summary>
        /// The deployment ID. Never <c>null</c>.
        /// </summary>
        public string DeploymentId { get; }

        /// <summary>
        /// The config ID. Never <c>null</c>.
        /// </summary>
        public string ConfigId { get; }

        /// <inheritdoc />
        public gax::ResourceNameKind Kind => gax::ResourceNameKind.Simple;

        /// <inheritdoc />
        public override string ToString() => s_template.Expand(DeploymentId, ConfigId);

        /// <inheritdoc />
        public override int GetHashCode() => ToString().GetHashCode();

        /// <inheritdoc />
        public override bool Equals(object obj) => Equals(obj as ConfigName);

        /// <inheritdoc />
        public bool Equals(ConfigName other) => ToString() == other?.ToString();

        /// <inheritdoc />
        public static bool operator ==(ConfigName a, ConfigName b) => ReferenceEquals(a, b) || (a?.Equals(b) ?? false);

        /// <inheritdoc />
        public static bool operator !=(ConfigName a, ConfigName b) => !(a == b);
    }

    /// <summary>
    /// Resource name for the 'deployment' resource.
    /// </summary>
    public sealed partial class DeploymentName : gax::IResourceName, sys::IEquatable<DeploymentName>
    {
        private static readonly gax::PathTemplate s_template = new gax::PathTemplate("deployments/{deployment}");

        /// <summary>
        /// Parses the given deployment resource name in string form into a new
        /// <see cref="DeploymentName"/> instance.
        /// </summary>
        /// <param name="deploymentName">The deployment resource name in string form. Must not be <c>null</c>.</param>
        /// <returns>The parsed <see cref="DeploymentName"/> if successful.</returns>
        public static DeploymentName Parse(string deploymentName)
        {
            gax::GaxPreconditions.CheckNotNull(deploymentName, nameof(deploymentName));
            gax::TemplatedResourceName resourceName = s_template.ParseName(deploymentName);
            return new DeploymentName(resourceName[0]);
        }

        /// <summary>
        /// Tries to parse the given deployment resource name in string form into a new
        /// <see cref="DeploymentName"/> instance.
        /// </summary>
        /// <remarks>
        /// This method still throws <see cref="sys::ArgumentNullException"/> if <paramref name="deploymentName"/> is null,
        /// as this would usually indicate a programming error rather than a data error.
        /// </remarks>
        /// <param name="deploymentName">The deployment resource name in string form. Must not be <c>null</c>.</param>
        /// <param name="result">When this method returns, the parsed <see cref="DeploymentName"/>,
        /// or <c>null</c> if parsing fails.</param>
        /// <returns><c>true</c> if the name was parsed successfully; <c>false</c> otherwise.</returns>
        public static bool TryParse(string deploymentName, out DeploymentName result)
        {
            gax::GaxPreconditions.CheckNotNull(deploymentName, nameof(deploymentName));
            gax::TemplatedResourceName resourceName;
            if (s_template.TryParseName(deploymentName, out resourceName))
            {
                result = new DeploymentName(resourceName[0]);
                return true;
            }
            else
            {
                result = null;
                return false;
            }
        }

        /// <summary>
        /// Constructs a new instance of the <see cref="DeploymentName"/> resource name class
        /// from its component parts.
        /// </summary>
        /// <param name="deploymentId">The deployment ID. Must not be <c>null</c>.</param>
        public DeploymentName(string deploymentId)
        {
            DeploymentId = gax::GaxPreconditions.CheckNotNull(deploymentId, nameof(deploymentId));
        }

        /// <summary>
        /// The deployment ID. Never <c>null</c>.
        /// </summary>
        public string DeploymentId { get; }

        /// <inheritdoc />
        public gax::ResourceNameKind Kind => gax::ResourceNameKind.Simple;

        /// <inheritdoc />
        public override string ToString() => s_template.Expand(DeploymentId);

        /// <inheritdoc />
        public override int GetHashCode() => ToString().GetHashCode();

        /// <inheritdoc />
        public override bool Equals(object obj) => Equals(obj as DeploymentName);

        /// <inheritdoc />
        public bool Equals(DeploymentName other) => ToString() == other?.ToString();

        /// <inheritdoc />
        public static bool operator ==(DeploymentName a, DeploymentName b) => ReferenceEquals(a, b) || (a?.Equals(b) ?? false);

        /// <inheritdoc />
        public static bool operator !=(DeploymentName a, DeploymentName b) => !(a == b);
    }

    /// <summary>
    /// Resource name for the 'group' resource.
    /// </summary>
    public sealed partial class GroupName : gax::IResourceName, sys::IEquatable<GroupName>
    {
        private static readonly gax::PathTemplate s_template = new gax::PathTemplate("deployments/{deployment}/groups/{group}");

        /// <summary>
        /// Parses the given group resource name in string form into a new
        /// <see cref="GroupName"/> instance.
        /// </summary>
        /// <param name="groupName">The group resource name in string form. Must not be <c>null</c>.</param>
        /// <returns>The parsed <see cref="GroupName"/> if successful.</returns>
        public static GroupName Parse(string groupName)
        {
            gax::GaxPreconditions.CheckNotNull(groupName, nameof(groupName));
            gax::TemplatedResourceName resourceName = s_template.ParseName(groupName);
            return new GroupName(resourceName[0], resourceName[1]);
        }

        /// <summary>
        /// Tries to parse the given group resource name in string form into a new
        /// <see cref="GroupName"/> instance.
        /// </summary>
        /// <remarks>
        /// This method still throws <see cref="sys::ArgumentNullException"/> if <paramref name="groupName"/> is null,
        /// as this would usually indicate a programming error rather than a data error.
        /// </remarks>
        /// <param name="groupName">The group resource name in string form. Must not be <c>null</c>.</param>
        /// <param name="result">When this method returns, the parsed <see cref="GroupName"/>,
        /// or <c>null</c> if parsing fails.</param>
        /// <returns><c>true</c> if the name was parsed successfully; <c>false</c> otherwise.</returns>
        public static bool TryParse(string groupName, out GroupName result)
        {
            gax::GaxPreconditions.CheckNotNull(groupName, nameof(groupName));
            gax::TemplatedResourceName resourceName;
            if (s_template.TryParseName(groupName, out resourceName))
            {
                result = new GroupName(resourceName[0], resourceName[1]);
                return true;
            }
            else
            {
                result = null;
                return false;
            }
        }

        /// <summary>
        /// Constructs a new instance of the <see cref="GroupName"/> resource name class
        /// from its component parts.
        /// </summary>
        /// <param name="deploymentId">The deployment ID. Must not be <c>null</c>.</param>
        /// <param name="groupId">The group ID. Must not be <c>null</c>.</param>
        public GroupName(string deploymentId, string groupId)
        {
            DeploymentId = gax::GaxPreconditions.CheckNotNull(deploymentId, nameof(deploymentId));
            GroupId = gax::GaxPreconditions.CheckNotNull(groupId, nameof(groupId));
        }

        /// <summary>
        /// The deployment ID. Never <c>null</c>.
        /// </summary>
        public string DeploymentId { get; }

        /// <summary>
        /// The group ID. Never <c>null</c>.
        /// </summary>
        public string GroupId { get; }

        /// <inheritdoc />
        public gax::ResourceNameKind Kind => gax::ResourceNameKind.Simple;

        /// <inheritdoc />
        public override string ToString() => s_template.Expand(DeploymentId, GroupId);

        /// <inheritdoc />
        public override int GetHashCode() => ToString().GetHashCode();

        /// <inheritdoc />
        public override bool Equals(object obj) => Equals(obj as GroupName);

        /// <inheritdoc />
        public bool Equals(GroupName other) => ToString() == other?.ToString();

        /// <inheritdoc />
        public static bool operator ==(GroupName a, GroupName b) => ReferenceEquals(a, b) || (a?.Equals(b) ?? false);

        /// <inheritdoc />
        public static bool operator !=(GroupName a, GroupName b) => !(a == b);
    }

    /// <summary>
    /// Resource name for the 'member' resource.
    /// </summary>
    public sealed partial class MemberName : gax::IResourceName, sys::IEquatable<MemberName>
    {
        private static readonly gax::PathTemplate s_template = new gax::PathTemplate("deployments/{deployment}/groups/{group}/members/{member}");

        /// <summary>
        /// Parses the given member resource name in string form into a new
        /// <see cref="MemberName"/> instance.
        /// </summary>
        /// <param name="memberName">The member resource name in string form. Must not be <c>null</c>.</param>
        /// <returns>The parsed <see cref="MemberName"/> if successful.</returns>
        public static MemberName Parse(string memberName)
        {
            gax::GaxPreconditions.CheckNotNull(memberName, nameof(memberName));
            gax::TemplatedResourceName resourceName = s_template.ParseName(memberName);
            return new MemberName(resourceName[0], resourceName[1], resourceName[2]);
        }

        /// <summary>
        /// Tries to parse the given member resource name in string form into a new
        /// <see cref="MemberName"/> instance.
        /// </summary>
        /// <remarks>
        /// This method still throws <see cref="sys::ArgumentNullException"/> if <paramref name="memberName"/> is null,
        /// as this would usually indicate a programming error rather than a data error.
        /// </remarks>
        /// <param name="memberName">The member resource name in string form. Must not be <c>null</c>.</param>
        /// <param name="result">When this method returns, the parsed <see cref="MemberName"/>,
        /// or <c>null</c> if parsing fails.</param>
        /// <returns><c>true</c> if the name was parsed successfully; <c>false</c> otherwise.</returns>
        public static bool TryParse(string memberName, out MemberName result)
        {
            gax::GaxPreconditions.CheckNotNull(memberName, nameof(memberName));
            gax::TemplatedResourceName resourceName;
            if (s_template.TryParseName(memberName, out resourceName))
            {
                result = new MemberName(resourceName[0], resourceName[1], resourceName[2]);
                return true;
            }
            else
            {
                result = null;
                return false;
            }
        }

        /// <summary>
        /// Constructs a new instance of the <see cref="MemberName"/> resource name class
        /// from its component parts.
        /// </summary>
        /// <param name="deploymentId">The deployment ID. Must not be <c>null</c>.</param>
        /// <param name="groupId">The group ID. Must not be <c>null</c>.</param>
        /// <param name="memberId">The member ID. Must not be <c>null</c>.</param>
        public MemberName(string deploymentId, string groupId, string memberId)
        {
            DeploymentId = gax::GaxPreconditions.CheckNotNull(deploymentId, nameof(deploymentId));
            GroupId = gax::GaxPreconditions.CheckNotNull(groupId, nameof(groupId));
            MemberId = gax::GaxPreconditions.CheckNotNull(memberId, nameof(memberId));
        }

        /// <summary>
        /// The deployment ID. Never <c>null</c>.
        /// </summary>
        public string DeploymentId { get; }

        /// <summary>
        /// The group ID. Never <c>null</c>.
        /// </summary>
        public string GroupId { get; }

        /// <summary>
        /// The member ID. Never <c>null</c>.
        /// </summary>
        public string MemberId { get; }

        /// <inheritdoc />
        public gax::ResourceNameKind Kind => gax::ResourceNameKind.Simple;

        /// <inheritdoc />
        public override string ToString() => s_template.Expand(DeploymentId, GroupId, MemberId);

        /// <inheritdoc />
        public override int GetHashCode() => ToString().GetHashCode();

        /// <inheritdoc />
        public override bool Equals(object obj) => Equals(obj as MemberName);

        /// <inheritdoc />
        public bool Equals(MemberName other) => ToString() == other?.ToString();

        /// <inheritdoc />
        public static bool operator ==(MemberName a, MemberName b) => ReferenceEquals(a, b) || (a?.Equals(b) ?? false);

        /// <inheritdoc />
        public static bool operator !=(MemberName a, MemberName b) => !(a == b);
    }

    /// <summary>
    /// Resource name for the 'package_path' resource.
    /// </summary>
    public sealed partial class PackagePathName : gax::IResourceName, sys::IEquatable<PackagePathName>
    {
        private static readonly gax::PathTemplate s_template = new gax::PathTemplate("deployments/{deployment}/packages/{package_path=**}");

        /// <summary>
        /// Parses the given package_path resource name in string form into a new
        /// <see cref="PackagePathName"/> instance.
        /// </summary>
        /// <param name="packagePathName">The package_path resource name in string form. Must not be <c>null</c>.</param>
        /// <returns>The parsed <see cref="PackagePathName"/> if successful.</returns>
        public static PackagePathName Parse(string packagePathName)
        {
            gax::GaxPreconditions.CheckNotNull(packagePathName, nameof(packagePathName));
            gax::TemplatedResourceName resourceName = s_template.ParseName(packagePathName);
            return new PackagePathName(resourceName[0], resourceName[1]);
        }

        /// <summary>
        /// Tries to parse the given package_path resource name in string form into a new
        /// <see cref="PackagePathName"/> instance.
        /// </summary>
        /// <remarks>
        /// This method still throws <see cref="sys::ArgumentNullException"/> if <paramref name="packagePathName"/> is null,
        /// as this would usually indicate a programming error rather than a data error.
        /// </remarks>
        /// <param name="packagePathName">The package_path resource name in string form. Must not be <c>null</c>.</param>
        /// <param name="result">When this method returns, the parsed <see cref="PackagePathName"/>,
        /// or <c>null</c> if parsing fails.</param>
        /// <returns><c>true</c> if the name was parsed successfully; <c>false</c> otherwise.</returns>
        public static bool TryParse(string packagePathName, out PackagePathName result)
        {
            gax::GaxPreconditions.CheckNotNull(packagePathName, nameof(packagePathName));
            gax::TemplatedResourceName resourceName;
            if (s_template.TryParseName(packagePathName, out resourceName))
            {
                result = new PackagePathName(resourceName[0], resourceName[1]);
                return true;
            }
            else
            {
                result = null;
                return false;
            }
        }

        /// <summary>
        /// Constructs a new instance of the <see cref="PackagePathName"/> resource name class
        /// from its component parts.
        /// </summary>
        /// <param name="deploymentId">The deployment ID. Must not be <c>null</c>.</param>
        /// <param name="packagePathId">The packagePath ID. Must not be <c>null</c>.</param>
        public PackagePathName(string deploymentId, string packagePathId)
        {
            DeploymentId = gax::GaxPreconditions.CheckNotNull(deploymentId, nameof(deploymentId));
            PackagePathId = gax::GaxPreconditions.CheckNotNull(packagePathId, nameof(packagePathId));
        }

        /// <summary>
        /// The deployment ID. Never <c>null</c>.
        /// </summary>
        public string DeploymentId { get; }

        /// <summary>
        /// The packagePath ID. Never <c>null</c>.
        /// </summary>
        public string PackagePathId { get; }

        /// <inheritdoc />
        public gax::ResourceNameKind Kind => gax::ResourceNameKind.Simple;

        /// <inheritdoc />
        public override string ToString() => s_template.Expand(DeploymentId, PackagePathId);

        /// <inheritdoc />
        public override int GetHashCode() => ToString().GetHashCode();

        /// <inheritdoc />
        public override bool Equals(object obj) => Equals(obj as PackagePathName);

        /// <inheritdoc />
        public bool Equals(PackagePathName other) => ToString() == other?.ToString();

        /// <inheritdoc />
        public static bool operator ==(PackagePathName a, PackagePathName b) => ReferenceEquals(a, b) || (a?.Equals(b) ?? false);

        /// <inheritdoc />
        public static bool operator !=(PackagePathName a, PackagePathName b) => !(a == b);
    }



}